==> sddm_0.11.0.orig.tar.gz: sddm-0.11.0/data/translations/it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Benvenuto in %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Attenzione, il blocco maiuscole è attivo!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Accedi</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Accesso fallito</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Accesso eseguito</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Inserisci nome utente e password</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Sessione</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Seleziona il tuo utente ed inserisci la password</translation>
    </message>
</context>
</TS>

==> sddm_0.19.0.orig.tar.gz: sddm-0.19.0/data/translations/it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Benvenuto in %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Attenzione, il blocco maiuscole è attivo!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Accedi</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Accesso non riuscito</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Accesso eseguito</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Inserisci nome utente e password</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Sessione</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Seleziona il tuo utente ed inserisci la password</translation>
    </message>
</context>
</TS>
